/** @jsx jsx */
import { jsx, css, Global } from '@emotion/core';
import * as React from 'react';
import { SkipNavLink, useTheme } from 'sancho';
import { Router } from '@reach/router';
import useThemeMode from '../hooks/useThemeMode';
import Main from './Main';

import Register from '../routes/Register';
import Login from '../routes/Login';

import Dashboard from '../routes/Dashboard';
import Settings from '../routes/Settings';
import Account from './../routes/Account';

import { AccountProvider } from '../hooks/useAccount';

const App: React.FC = () => {
  const { isLightTheme, ThemeMode } = useThemeMode();
  const theme = useTheme();
  const bgColor = isLightTheme
    ? theme.colors.background.default
    : theme.colors.palette.gray.dark;
  return (
    <AccountProvider>
      <div>
        <SkipNavLink />
        <ThemeMode>
          <div>
            <Router>
              <Register path="register" />
              <Login path="login" />
              <Main path="/">
                <Dashboard path="dashboard" />
                <Account path="account/*" />
                <Settings path="settings" />
              </Main>
            </Router>
          </div>
        </ThemeMode>
        <Global
          styles={css`
            html {
              background-color: ${bgColor} !important;
            }

            body {
              margin: 0;
              padding: 0;
            }
          `}
        />
      </div>
    </AccountProvider>
  );
};

export default App;
