import * as React from 'react';
import { useQuery } from 'react-apollo-hooks';
import gql from 'graphql-tag';
import { get } from 'lodash';

const ME = gql`
  query me {
    me {
      id
      username
      email
      firstname
      lastname
      gender
      mobilePhone
      wechat
      qqnumber
      currency
      language
      role
      nickname
      dateTimeCreated
      ... on Member {
        totalBalance
        availableBalance
        bankAccount {
          id
          bank
          accountName
          accountNumber
          province
          country
          city
          branch
          __typename
        }
        __typename
      }
      ... on Agent {
        balance
        nickname
        gender
        mobilePhone
        wechat
        qqnumber
        __typename
      }
      __typename
    }
  }
`;

const AccountContext = React.createContext({
  account: null,
});

export const AccountProvider = ({ children }: React.PropsWithChildren<{}>) => {
  const accessToken = localStorage.getItem('accessToken');
  const { data, error, loading } = useQuery(ME, { skip: !accessToken });
  if (loading) {
    return <div>Loading...</div>;
  }
  if (error) {
    return <div>Error! {error.message}</div>;
  }
  return (
    <AccountContext.Provider value={{ account: get(data, 'me') }}>
      {children}
    </AccountContext.Provider>
  );
};

export const useAccountValue = () => React.useContext(AccountContext);
