/** @jsx jsx */
import { jsx, css } from '@emotion/core';
import * as React from 'react';
import { RouteComponentProps, Router } from '@reach/router';
import { Tabs, Tab, Text, useTheme } from 'sancho';

import Profile from './Profile';
import Billing from './Billing';

import noOp from '../../utils/noOp';
import useThemeMode from './../../hooks/useThemeMode';

const Account: React.FC<RouteComponentProps | any> = props => {
  const currentTab = props['*'];
  const { isLightTheme } = useThemeMode();
  const theme = useTheme();
  const pageTabs = ['profile', 'billing'];
  const currentTabIndex = pageTabs.findIndex(value => value === currentTab);
  return (
    <div>
      <Text variant="h1">Account</Text>
      <Tabs
        variant="default"
        value={currentTabIndex}
        onChange={noOp}
        css={css`
          margin-bottom: 1.5rem;
          position: relative;
          box-shadow: none;
          &:after {
            content: '';
            height: 2px;
            background: ${isLightTheme
              ? theme.colors.intent.none.lightest
              : theme.colors.intent.none.base};
            width: 100%;
            position: absolute;
            bottom: 0;
            left: 0;
          }
          button {
            padding: 10px 0rem;
            margin-right: 1rem;
            span {
              font-size: 1rem;
            }
          }
          .Tabs__container {
            transform: none;
          }
          .Tabs__slider {
            height: 2px;
            z-index: 20;
            border-radius: 0;
            margin: 0 -0.5rem;
          }
        `}
      >
        <Tab id="profile" onPress={() => props.navigate('/account/profile')}>
          Profile
        </Tab>
        <Tab id="billing" onPress={() => props.navigate('/account/billing')}>
          Billing
        </Tab>
      </Tabs>
      <Router>
        <Profile path="profile" />
        <Billing path="billing" />
      </Router>
    </div>
  );
};

export default Account;
