/** @jsx jsx */
import { jsx, css } from '@emotion/core';
import * as React from 'react';
import { RouteComponentProps, Link } from '@reach/router';
import { Text, Layer, InputGroup, Input, Button } from 'sancho';
import { Redirect } from '@reach/router';
import { useAccountValue } from '../../hooks/useAccount';

const Register: React.FC<RouteComponentProps> = () => {
  const { account } = useAccountValue();
  if (account) return <Redirect to="/dashboard" noThrow />;
  return (
    <Layer
      elevation="xs"
      css={css`
        max-width: 450px;
        margin: 5rem auto 0;
        padding: 2rem;
      `}
    >
      <Text
        variant="h1"
        css={css`
          text-align: center;
          margin-bottom: 2rem;
        `}
      >
        Create new account
      </Text>
      <div
        css={css`
          margin-bottom: 1rem;
        `}
      >
        <form>
          <InputGroup
            label="Email address"
            css={css`
              margin-bottom: 1rem;
            `}
          >
            <Input placeholder="ben.mcmahen@gmail.com" />
          </InputGroup>
          <Button intent="primary" block>
            Create account
          </Button>
        </form>
      </div>
      <Text
        variant="subtitle"
        css={css`
          text-align: center;
          margin-bottom: 1rem;
        `}
      >
        By signing up, you agreed to our{' '}
        <Link to="#target">User Terms of Service</Link> and <br />
        <Link to="#target">Privacy Policy</Link>.
      </Text>
      <Text
        variant="subtitle"
        css={css`
          text-align: center;
        `}
      >
        Already have an account? <Link to="/login">Sign in</Link>
      </Text>
    </Layer>
  );
};

export default Register;
